#
# spec file for package python-pyroute2
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pyroute2
Version:        0.4.19
Release:        15.1
Summary:        Python Netlink library
License:        GPL-2.0+ or Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/svinota/pyroute2
Source:         https://files.pythonhosted.org/packages/source/p/pyroute2/pyroute2-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  python-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%python_subpackages

%description
Pyroute2 is a pure Python **netlink** and Linux **network configuration**
library. It requires only Python stdlib, no 3rd party libraries.
Later it can change, but the deps tree will remain as simple, as
it is possible.

The library provides several modules:

* Netlink protocol implementations (RTNetlink, TaskStats, etc)
    * **rtnl**, network settings --- addresses, routes, traffic controls
    * **nl80211** --- wireless functions API (work in progress)
    * **nfnetlink** --- netfilter API: **ipset** (work in progress), ...
    * **ipq** --- simplest userspace packet filtering, iptables QUEUE target
    * **taskstats** --- extended process statistics
* Simple netlink socket object, that can be used in poll/select
* Network configuration module IPRoute provides API that in some
  way resembles ip/tc functionality
* IPDB is an async transactional database of Linux network settings

%prep
%setup -q -n pyroute2-%{version}

%build
%python_build

%install
%python_install

%files %{python_files}
%defattr(-,root,root,-)
%doc README.make.md README.packages.md README.md LICENSE.Apache.v2 CHANGELOG.md LICENSE.GPL.v2 README.license.md
%{python_sitelib}/*

%changelog
* Fri Aug 25 2017 tbechtold@suse.com
- update to 0.4.19:
  * ipdb: global methods `review()`, `drop()`, `dump()`, `load()`
  * ipdb: support VLAN protocol (802.1q, 802.1ad)
  * ipdb: initial support for IPv6 rules
  * ipdb: #388 -- normalize IPv6 addresses
  * ipdb: #391 -- support both IPv4 and IPv6 default routes
  * ipdb: #394 -- correctly work with route priorities
  * netns: non-destructive `netns.create()`
* Fri Aug 25 2017 tbechtold@suse.com
- update to 0.4.18:
  * ipdb: #379 [critical] -- routes in global commits
  * ipdb: #380 -- global commit with disabled plugins
  * ipdb: #381 -- exceptions fixed
  * ipdb: #382 -- manage dependent routes during interface commits
  * ipdb: #384 -- global `review()`
  * ipdb: #385 -- global `drop()`
  * netns: #383 -- support ppc64
  * general: public API refactored (same signatures; to be documented)
* Mon Jul 10 2017 tbechtold@suse.com
- update to 0.4.17:
  * req: #374 [critical] -- mode nla init
  * iproute: #378 [critical] -- fix `flush_routes()` to respect filters
  * ifinfmsg: #376 -- fix data plugins API to support pyinstaller
  * ipdb: race fixed: remove port/bridge
  * ipdb: #280 -- race fixed: port/bridge
  * ipdb: #302 -- ipaddr views: [ifname].ipaddr.ipv4, [ifname]ipaddr.ipv6
  * ipdb: #357 -- allow bridge timings to have some delta
  * ipdb: #338 -- allow to fix interface objects from failed `create()`
  * rtnl: #336 -- fix vlan flags
  * iproute: #342 -- the match method takes any callable
  * nlsocket: #367 -- increase default SO_SNDBUF
  * ifinfmsg: support tuntap on armv6l, armv7l platforms
- convert to singlespec
* Tue Jun 13 2017 dmueller@suse.com
- update to 0.4.15:
  * req: #365 -- full and short nla notation fixed, critical
  * iproute: #364 -- new method, `brport()`
  * ipdb: -- support bridge port options
  * event: new genl protocols set: VFS_DQUOT, acpi_event, thermal_event
  * ipdb: #310 -- fixed priority change on routes
  * ipdb: #349 -- fix setting ifalias on interfaces
  * ipdb: #353 -- mitigate kernel oops during bridge creation
  * ipdb: #354 -- allow to explicitly choose plugins to load
  * ipdb: #359 -- provide read-only context managers
  * rtnl: #336 -- vlan flags support
  * rtnl: #352 -- support interface type plugins
  * tc: #344 -- mirred action
  * tc: #346 -- connmark action
  * netlink: #358 -- memory optimization
  * config: #360 -- generic asyncio config
  * iproute: #362 -- allow to change or replace a qdisc
  * ipset: full rework of the IPSET_ATTR_DATA and IPSET_ATTR_ADT
    ACHTUNG: this commit may break API compatibility
  * ipset: hash:mac support
  * ipset: list:set support
  * ipdb: throw EEXIST when creates VLAN/VXLAN devs with same ID, but
    under different names
  * tests: #329 -- include unit tests into the bundle
  * legal: E/// logo removed
* Tue Jan 10 2017 dmueller@suse.com
- update to 0.4.12:
  * ipdb: #314 -- let users choose RTNL groups IPDB listens to
  * ipdb: #321 -- isolate `net_ns_.*` setup in a separate code block
  * ipdb: #322 -- IPv6 updates on interfaces in DOWN state
  * ifinfmsg: allow absolute/relative paths in the net_ns_fd NLA
  * ipset: #323 -- support setting counters on ipset add
  * ipset: `headers()` command
  * ipset: revisions
  * ipset: #326 -- mark types
* Mon Nov 21 2016 glin@suse.com
- Update to 0.4.11
  + rtnl: #284 -- support vlan_flags
  + ipdb: #288 -- do not inore link-local addresses
  + ipdb: #300 -- sort ip addresses
  + ipdb: #306 -- support net_ns_pid
  + ipdb: #307 -- fix IPv6 routes management
  + ipdb: #311 -- vlan interfaces address loading
  + iprsocket: #305 -- support NETLINK_LISTEN_ALL_NSID
  + devlink: fix fd leak on broken init
  + sock_diag: initial NETLINK_SOCK_DIAG support
  + rtnl: fix critical fd leak in the compat code
  + rtnl: compat proxying fix
  + rtnl: compat code is back
  + netns: custom netns path support
  + ipset: multiple improvements
* Tue Nov 15 2016 dmueller@suse.com
- update to 0.4.6:
  * ipdb: #278 -- fix initial ports mapping
  * ipset: #277 -- fix ADT attributes parsing
  * nl80211: #274, #275, #276 -- BSS-related fixes
* Mon Aug  8 2016 glin@suse.com
- Update Source url to pass the check in openSUSE:Factory
* Mon Aug  8 2016 glin@suse.com
- Update to 0.4.5
  + ifinfmsg: GTP interfaces support
  + generic: devlink protocol support
  + generic: code cleanup
  + iproute: #262 -- `get_vlans()` fix
  + iproute: default mask 32 for IPv4 in `addr()`
  + rtmsg: #260 -- RTA_FLOW support
  + ipdb: #259 -- critical `Interface` class fix
  + benchmark: initial release
  + ipdb: event modules
  + ipdb: on-demand views
  + ipdb: rules management
  + ipdb: bridge controls
  + ipdb: #258 -- important Python compatibility fixes
  + netns: #257 -- pipe leak fix
  + netlink: support pickling for nlmsg
  + netlink: no buffer copying in the parser
  + netlink: parse NLA on demand
  + ipdb: #244 -- lwtunnel multipath fixes
  + iproute: #235 -- route types
  + docs updated
* Sun May  8 2016 michael@stroeder.com
- Update to 0.4.0
* Fri Dec 11 2015 glin@suse.com
- Update to 0.3.15
* Fri Nov  6 2015 glin@suse.com
- initial import 0.3.14
